Type

Struct Type 

pub struct Type {
    pub namespace: Vec<String>,
    pub name: String,
    pub bare: bool,
    pub generic_ref: bool,
    pub generic_arg: Option<Box<Type>>,
}
The type of a definition or a parameter, e.g. ns.Vector<!X>.

Fields

namespace: Vec<String>

Namespace components, e.g. ["upload"] for upload.File.

name: String

The bare type name, e.g. "Vector".

bare: bool

true when the first letter of the name is lowercase (bare type).

generic_ref: bool

true when this type is a generic parameter reference (prefixed with !).

generic_arg: Option<Box<Type>>

The generic argument, e.g. long in Vector<long>.