Module tl

Module tl 

Rust types representing the Abstract Syntax Tree of a TL definition.

Structs

Definition
A single TL definition — either a constructor or a function.
Flag
A flag reference inside a parameter type, e.g. flags.0 in flags.0?true.
Parameter
A single name:Type parameter inside a TL definition.
Type
The type of a definition or a parameter, e.g. ns.Vector<!X>.

Enums

Category
Whether a super::Definition is a data constructor or an RPC function.
ParameterType
The kind of a single TL parameter.